# AirField

Dataclasses that describe how Pydantic model fields should be presented in any UI context: web forms, CLI prompts, data tables, notebooks, API docs, charts.

## Getting started

- [Installation](installation.md) - how to install AirField
- [Usage](usage.md) - how to use AirField
- [API Reference](api.md) - auto-generated API documentation
